pub fn export_point_cloud_device_array(
cloud: &PointCloud,
) -> ArrowBridgeResult<ExportedArrowDeviceArray>Expand description
Exports a point cloud as an Arrow device array on CPU.
pub fn export_point_cloud_device_array(
cloud: &PointCloud,
) -> ArrowBridgeResult<ExportedArrowDeviceArray>Exports a point cloud as an Arrow device array on CPU.